<div align="center">
    <img src="https://raw.githubusercontent.com/yut-kt/charmeleon/main/asset/logo.png" alt="charmeleon logo" style="width: 50%">
    <h2><strong>charmeleon</strong> is a character conversion library in Python.</h2>
    <a href="https://pypi.org/project/charmeleon/"><img src="https://img.shields.io/pypi/v/charmeleon" alt="PyPI - Version"></a>
    <img src="https://github.com/yut-kt/charmeleon/actions/workflows/push-main-ci.yaml/badge.svg" alt="workflow" />
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/yut-kt/charmeleon/main/asset/coverage.json" alt="coverage" />
    <a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License: MIT"></a>
</div>

# Install
```bash
$ pip install charmeleon
 ```

# Usage
Please read the [Document](https://yut-kt.github.io/charmeleon/modules.html>).
